<?php namespace EscapeWork\Manager\Console;

use EscapeWork\Manager\Models\User;
use EscapeWork\Manager\Seeders\ManagerSeeder;
use EscapeWork\Manager\Repositories\UserRepository;
use Illuminate\Console\Command;
use Symfony\Component\Console\Input\InputOption;
use Symfony\Component\Console\Input\InputArgument;
use Config;

class ConfigureCommand extends Command
{

    /**
     * The console command name.
     *
     * @var string
     */
    protected $name = 'manager:configure';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Migrations, Seeds, plugins e tudo que precisar ser configurado.';

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct(UserRepository $user)
    {
        parent::__construct();

        $this->user = $user;
    }

    /**
     * Execute the console command.
     *
     * @return void
     */
    public function fire()
    {
        $this->comment('--- Configurando escapework/manager ---');

        # vendor:publish
        $this->comment('Publicando os arquivos do escapework/manager...');
        $this->call('vendor:publish');
        $this->info(' -> Arquivos do escapework/manager publicados!');
        $this->line('');

        # migrations
        $this->comment('Fazendo as migrations...');
        $this->call('migrate', ['--force' => true]);
        $this->info(' -> Migrations realizadas');
        $this->line('');

        # seed
        $this->comment('Fazendo os seeds...');
        $seeder = new ManagerSeeder();
        $seeder->setContainer($this->laravel)->setCommand($this)->run();
        $this->info(' -> escapework/manager seeded!');
        $this->line('');

        if (User::count() == 0) {
            $this->comment('É necessário criar o primeiro usuário.');
            $this->call('manager:user:create');
        }

        $this->line('');
        $this->comment('--------------------------------------------');
        $this->comment('------ <info>escapework/manager configurado</info> ------');
        $this->comment('--------------------------------------------');
        $this->line('');
    }
}
