<?php namespace EscapeWork\Manager\Console;

use Symfony\Component\Console\Input\InputOption;

class ControllerMakeCommand extends GeneratorCommand
{

    /**
     * The console command name.
     *
     * @var string
     */
    protected $name = 'manager:make:controller';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Create a new resource controller class';

    /**
     * The type of class being generated.
     *
     * @var string
     */
    protected $type = 'Controller';

    /**
     * Get the stub file for the generator.
     *
     * @return string
     */
    protected function getStub()
    {
        return __DIR__.'/../../resources/stubs/controller.stub';
    }

    /**
     * Get the default namespace for the class.
     *
     * @param  string  $rootNamespace
     * @return string
     */
    protected function getDefaultNamespace($rootNamespace)
    {
        return $rootNamespace.'\Http\Controllers\Manager';
    }

    public function replaceSpecific($stub, $name)
    {
        $stub = str_replace('{{repository}}', $this->option('repository'), $stub);
        $stub = str_replace('{{title}}', mb_strtolower($this->option('title')), $stub);
        $stub = str_replace('{{createCommand}}', $this->option('createCommand'), $stub);
        $stub = str_replace('{{updateCommand}}', $this->option('updateCommand'), $stub);
        $stub = str_replace('{{destroyCommand}}', $this->option('destroyCommand'), $stub);
        $stub = str_replace('{{createRequest}}', $this->option('createRequest'), $stub);
        $stub = str_replace('{{updateRequest}}', $this->option('updateRequest'), $stub);

        return $stub;
    }

    public function getOptions()
    {
        return [
            ['repository', null, InputOption::VALUE_REQUIRED, 'The repository'],
            ['title', null, InputOption::VALUE_REQUIRED, 'The title of the resource'],
            ['createCommand', null, InputOption::VALUE_REQUIRED, 'The create command class'],
            ['updateCommand', null, InputOption::VALUE_REQUIRED, 'The update command class'],
            ['destroyCommand', null, InputOption::VALUE_REQUIRED, 'The destroy command class'],
            ['createRequest', null, InputOption::VALUE_REQUIRED, 'The create request class'],
            ['updateRequest', null, InputOption::VALUE_REQUIRED, 'The update request class'],
        ];
    }
}
