<?php namespace EscapeWork\Manager\Console;

use Illuminate\Console\Command;
use Illuminate\Support\Str;
use Symfony\Component\Console\Input\InputOption;
use Symfony\Component\Console\Input\InputArgument;

class CrudGeneratorCommand extends Command
{

    /**
     * The console command name.
     *
     * @var string
     */
    protected $name = 'manager:crud:generate';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Cria um CRUD base (Controller, Requests, Model, Repository e Commands)';

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Execute the console command.
     *
     * @return void
     */
    public function fire()
    {
        $name   = $this->ask(' -> Qual o nome do model que você deseja criar? Ex: Service, Member, Category, Product...');
        $plural = $this->ask(' -> Qual o plural do model que você deseja criar? Ex: Services, Members, Categories, Products...');
        $title  = $this->ask(' -> Qual o título do recurso que você deseja criar? Ex: Serviço, Categoria, Produto...');

        $title = ucfirst($title);
        $slug  = Str::slug($plural);
        $names = $this->getNames($name);
        $route = Str::slug($title) . 's';

        # criando o controller
        $this->call('manager:make:controller', [
            'variable'         => $names['variable'],
            'name'             => $names['controller'],
            '--title'          => $title,
            '--repository'     => $names['repository'],
            '--createCommand'  => $names['command']['subnamespace'] . '\\' . $names['command']['create'],
            '--updateCommand'  => $names['command']['subnamespace'] . '\\' . $names['command']['update'],
            '--destroyCommand' => $names['command']['subnamespace'] . '\\' . $names['command']['destroy'],
            '--createRequest'  => $names['request']['subnamespace'] . '\\' . $names['request']['create'],
            '--updateRequest'  => $names['request']['subnamespace'] . '\\' . $names['request']['update'],
        ]);

        # criando os requests
        $this->call('manager:make:request', [
            'variable'     => $names['variable'],
            'subnamespace' => $names['request']['subnamespace'],
            'name'         => $names['request']['create'],
            '--type'       => 'create',
        ]);

        $this->call('manager:make:request', [
            'variable'     => $names['variable'],
            'subnamespace' => $names['request']['subnamespace'],
            'name'         => $names['request']['update'],
            '--type'       => 'update',
        ]);

        # criando o model
        $this->call('manager:make:model', [
            'variable' => $names['variable'],
            'name'     => $names['model'],
            '--table'  => $names['table'],
        ]);

        # criando o repo
        $this->call('manager:make:repository', [
            'variable' => $names['variable'],
            'name'     => $names['repository'],
            '--model'  => $names['model'],
        ]);

        # criando os comandos
        $this->call('manager:make:command', [
            'variable'     => $names['variable'],
            'subnamespace' => $names['command']['subnamespace'],
            'name'         => $names['command']['create'],
            '--model'      => $names['model'],
            '--type'       => 'create',
        ]);

        $this->call('manager:make:command', [
            'variable'     => $names['variable'],
            'subnamespace' => $names['command']['subnamespace'],
            'name'         => $names['command']['update'],
            '--model'      => $names['model'],
            '--type'       => 'update',
        ]);

        $this->call('manager:make:command', [
            'variable'     => $names['variable'],
            'subnamespace' => $names['command']['subnamespace'],
            'name'         => $names['command']['destroy'],
            '--model'      => $names['model'],
            '--type'       => 'destroy',
        ]);

        # criando as views
        $this->call('manager:make:views', [
            'title'    => $title,
            'variable' => $names['variable'],
        ]);

        $this->line('');
        $this->info(' -> Seu CRUD foi gerado com sucesso!');

        $this->line('');
        $this->comment(' -> Registre as rotas abaixo no seu arquivo de rotas.');
        $this->info(' -> IMPORTANTE: Coloque estas rotas dentro de um grupo com o prefixo da URL do manager e validaçnao de autenticação!!!');
        $this->line("Route::get('".$route."', ['as' => 'manager.".$names['variable']."s.index', 'uses' => 'Manager\\".$names['controller']."@index']);");
        $this->line("Route::get('".$route."/create', ['as' => 'manager.".$names['variable']."s.create', 'uses' => 'Manager\\".$names['controller']."@create']);");
        $this->line("Route::post('".$route."', ['as' => 'manager.".$names['variable']."s.store', 'uses' => 'Manager\\".$names['controller']."@store']);");
        $this->line("Route::get('".$route."/{id}/edit', ['as' => 'manager.".$names['variable']."s.edit', 'uses' => 'Manager\\".$names['controller']."@edit']);");
        $this->line("Route::put('".$route."/{id}', ['as' => 'manager.".$names['variable']."s.update', 'uses' => 'Manager\\".$names['controller']."@update']);");
        $this->line("Route::delete('".$route."/{id}', ['as' => 'manager.".$names['variable']."s.destroy', 'uses' => 'Manager\\".$names['controller']."@destroy']);");

        # adicionando no menu
        $html = '<li class="{{ $page == \''.$names['variable'].'s\' ? \'active\' : null }}">
    <a href="{{ route(\'manager.'.$names['variable'].'s.index\') }}">'.$title.'s</a>
</li>';

        if (\File::exists($menu = base_path().'/resources/views/manager/menu.blade.php')) {
            \File::append($menu, "\n" . $html);

            $this->line('');
            $this->info(' -> Adicionamos o HTML com o link na view do menu (resources/views/manager/menu.blade)');
        } else {
            $this->line('');
            $this->comment(' -> E adicione no seu menu');
            $this->line($html);
        }
    }

    protected function getNames($name)
    {
        return [
            'variable'   => strtolower($name),
            'table'      => strtolower($name) . 's',
            'controller' => $name . 'sController',
            'model'      => $name,
            'repository' => $name . 'Repository',

            'request' => [
                'subnamespace' => $name . 's',
                'create'       => $name . 'CreateRequest',
                'update'       => $name . 'UpdateRequest',
            ],

            'command' => [
                'subnamespace' => $name . 's',
                'create'       => $name . 'CreateCommand',
                'update'       => $name . 'UpdateCommand',
                'destroy'      => $name . 'DestroyCommand',
            ],
        ];
    }
}
