<?php namespace EscapeWork\Manager\Console;

use Illuminate\Console\Command;
use Illuminate\Filesystem\Filesystem;
use Symfony\Component\Console\Input\InputOption;
use Symfony\Component\Console\Input\InputArgument;

class ViewsMakeCommand extends Command
{

    /**
     * The console command name.
     *
     * @var string
     */
    protected $name = 'manager:make:views';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Cria as views para o CRUD';

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct(Filesystem $files)
    {
        parent::__construct();

        $this->files = $files;
    }

    public function fire()
    {
        $path = $this->laravel['path.base'] . '/resources/views/manager/' . $this->argument('variable') .'s';

        # criando o diretorio
        $this->makeDirectory($path);

        # criando a index
        $this->createView($path, 'index');
        $this->createView($path, 'create');
        $this->createView($path, 'edit');
        $this->createView($path, 'fields');

        $this->info('Views criadas com sucesso!');
    }

    protected function createView($path, $type)
    {
        $stub = $this->files->get($this->getStub($type));
        $stub = str_replace('{{variable}}', $this->argument('variable'), $stub);
        $stub = str_replace('{{title}}', $this->argument('title'), $stub);
        $stub = str_replace('{{titlelower}}', strtolower($this->argument('title')), $stub);

        if ($this->files->exists($path . '/' . $type . '.blade.php')) {
            $this->error('View ' . $type . ' já existe!');
            return;
        }

        $this->files->put(
            $path . '/' . $type . '.blade.php',
            $stub
        );
    }

    protected function getStub($type)
    {
        return __DIR__.'/../../resources/stubs/view-'.$type.'.stub';
    }

    protected function makeDirectory($path)
    {
        if (! $this->files->isDirectory($path)) {
            $this->files->makeDirectory($path, 0777, true, true);
        }
    }

    protected function getArguments()
    {
        return [
            ['variable', InputArgument::REQUIRED, 'The variable to replace in the controller stub.'],
            ['title', InputArgument::REQUIRED, 'The title of the resource'],
        ];
    }
}
