<?php namespace EscapeWork\Manager\Http\Controllers\Auth;

use EscapeWork\Manager\Facades\ManagerAuth;
use EscapeWork\Manager\Http\Controllers\Controller;
use EscapeWork\Manager\Extensions\Auth\Guard;
use EscapeWork\Manager\Http\Requests\Auth\LoginRequest;
use Illuminate\Http\Request;

class LoginController extends Controller
{

    public function __construct(Guard $auth)
    {
        $this->auth = $auth;
    }

    public function index()
    {
        return view(config('manager.views.login'));
    }

    public function login(LoginRequest $request)
    {
        $credentials = $request->only('email', 'password');

        if ($this->auth->attempt($credentials, $request->get('remember') == 1)) {
            return redirect(route(config('manager.redirects.after_login')))
                           ->with('message', trans('manager::login.messages.login-successfully'));
        }

        return redirect(route(config('manager.redirects.login')))
                       ->withInput()
                       ->with('error', trans('manager::login.errors.credentials'));
    }

    public function logout()
    {
        $this->auth->logout();

        return redirect(config('manager.redirects.logout'));
    }
}
