<?php namespace EscapeWork\Manager\Http\Controllers\Auth;

use EscapeWork\Manager\Http\Controllers\Controller;
use EscapeWork\Manager\Extensions\Auth\PasswordBroker;
use EscapeWork\Manager\Extensions\Auth\Guard;
use EscapeWork\Manager\Http\Requests\Password\PasswordSendRequest;
use EscapeWork\Manager\Http\Requests\Password\PasswordResetRequest;

class PasswordController extends Controller
{

    /**
     * @var EscapeWork\Manager\Extensions\Auth\PasswordBroker
     */
    protected $passwords;

    /**
     * @var EscapeWork\Manager\Extensions\Auth\Guard
     */
    protected $auth;

    public function __construct(PasswordBroker $passwords, Guard $auth)
    {
        parent::__construct();

        $this->passwords = $passwords;
        $this->auth      = $auth;
    }

    /**
     * Enviando um link para refazer a senha no email da pessoa
     */
    public function send(PasswordSendRequest $request)
    {
        $response = $this->passwords->sendResetLink($request->only('email'), function($m)
        {
            $m->subject('Seu lembrete de senha');
        });

        switch ($response)
        {
            case PasswordBroker::RESET_LINK_SENT:
                return redirect()->back()
                                ->with('message', trans('manager::password.msg.' . $response));

            case PasswordBroker::INVALID_USER:
                return redirect()->back()->with('error', trans('manager::validation.email.exists'));
        }
    }

    /**
     * Tela para refazer a senha
     */
    public function index($token)
    {
        return view('manager::auth.reset', [
            'token' => $token,
        ]);
    }

    /**
     * Resetando a senha no banco de dados
     */
    public function reset(PasswordResetRequest $request)
    {
        $credentials = $request->only(
            'email', 'password', 'password_confirmation', 'token'
        );

        $response = $this->passwords->reset($credentials, function($user, $password)
        {
            $user->password = $password;
            $user->save();

            $this->auth->login($user);
        });

        switch ($response)
        {
            case PasswordBroker::PASSWORD_RESET:
                return redirect(route('manager.home'))
                       ->with('message', trans('manager::password.msg.' . $response));

            default:
                return redirect()->back()
                                 ->withInput($request->only('email'))
                                 ->with('error', trans('manager::password.msg.' . $response));
        }
    }
}
