<?php namespace EscapeWork\Manager\Http\Controllers;

use EscapeWork\Manager\Repositories\UserRepository;
use EscapeWork\Manager\Repositories\RoleRepository;
use EscapeWork\Manager\Facades\ManagerAuth;
use EscapeWork\Manager\Http\Controllers\Controller;
use EscapeWork\Manager\Http\Requests\Users\UserCreateRequest;
use EscapeWork\Manager\Http\Requests\Users\UserUpdateRequest;
use Illuminate\Http\Request;

class UsersController extends Controller
{

    public function __construct(UserRepository $user, RoleRepository $role)
    {
        parent::__construct();

        $this->middleware('manager.hasPermission');

        $this->users = $user;
        $this->role  = $role;

        // $this->validatePermissions('users');
    }

    public function index()
    {
        return view(config('manager.views.users.index'), [
            'users' => $this->users->allowed(ManagerAuth::user()),
        ]);
    }

    public function create()
    {
        return view(config('manager.views.users.create'), [
            'user'  => $this->users,
            'roles' => $this->role->lists('title', 'id'),
        ]);
    }

    public function store(UserCreateRequest $request)
    {
        $user = $this->dispatchFrom('EscapeWork\Manager\Commands\Users\UserCreateCommand', $request, [
            'data' => $request->all(),
        ]);

        # disparando evento de usuário registrado
        # precisa ser implementado
        # event(new \EscapeWork\Manager\Events\UserWasRegistered);

        return redirect(route('manager.users.index'))
               ->with('message', trans('manager::users.messages.store', ['user' => $user->name]));
    }

    public function show($id, Request $request)
    {
        if ($request->ajax()) {
            return $this->users->find($id);
        }

        return redirect(route('manager.users.index'));
    }

    public function edit($id)
    {
        $user = $this->users->findOrFail($id);

        return view(config('manager.views.users.edit'), [
            'user'  => $user,
            'roles' => $this->role->lists('title', 'id'),
        ]);
    }

    public function update($id, UserUpdateRequest $request)
    {
        $user = $this->dispatchFrom('EscapeWork\Manager\Commands\Users\UserUpdateCommand', $request, [
            'id'   => $request->id,
            'data' => $request->all(),
        ]);

        return redirect(route('manager.users.index'))
               ->with('message', trans('manager::users.messages.update', ['user' => $user->name]));
    }

    public function destroy($id)
    {
        $user = $this->users->findOrFail($id);

        # verificando se o usuário logado não está tentando se excluir
        if (ManagerAuth::check() && $user->id == ManagerAuth::user()->id) {
            return redirect(route('manager.users.index'))
                    ->withErrors(trans('manager::users.error.delete'));
        }

        $user->delete();

        return redirect(route('manager.users.index'))
                ->with('message', trans('manager::users.messages.delete', ['user' => $user->name]));
    }
}
