<?php namespace EscapeWork\Manager;

use EscapeWork\Manager\Repositories\UserRepository;
use EscapeWork\Manager\Repositories\RoleActionRepository;
use EscapeWork\Manager\Exceptions\UnauthorizedExcpetion;

class Permission
{

    /**
     * Array of allowed pages
     *
     * @var  array
     */
  //  public $pages;

    /**
     * Array of allowed specific actions in specific pages
     *
     * @var  array
     */
    public $actions;

    /**
     * Initializing the Permission Class
     *
     * @param UserRepository       $user
     * @param RoleActionRepository $roleAction
     */
    public function __construct($user)
    {
        $this->user = $user;
    }

    /**
     * Fetching the allowed for the actual user
     *
     * @access  public
     * @return  void
     */
    public function fetchAllowedActions()
    {
        if (! $this->user) {
            return $this;
        }

        // $this->pages   = $this->user->role->pages;
        // $this->actions = $this->user->role->actions;
        // $this->actions->load('action');

        return $this;
    }

    /**
     * Checking if the user has permission to access determined page
     * If not, throw an EscapeWork\Manager\UnauthorizedExcpetion
     *
     * @param  string $page
     * @param  string $action
     */
    public function canOrFail($page, $action = null)
    {
        if (! $roleAction = $this->can($page, $action)) {
            throw new UnauthorizedExcpetion('Você não tem permissão para acessar esta página');
        }

        return $roleAction;
    }

    /**
     * Checking if the user has permission to access determined page
     *
     * @param   string $page
     * @param   string $action
     * @return  boolean
     */
    public function can($page, $action = null)
    {
        if ($this->user && $this->user->role->all_permissions) {
            return true;
        }

        return $this->user->role->pages->contains('page', $page);

        // if (! $this->pages->hasSlug($page)) {
        //     return false;
        // }

        // if ($action) {
        //     $page = $this->pages->bySlug($page);

        //     if (! $this->actions->hasPermission($page, $action)) {
        //         return false;
        //     }
        // }
    }

    /**
     * Checking if the user can access unless one action on some page
     * Normaly used for menus
     *
     * @access  public
     * @param   string $page
     * @return  boolean
     */
    public function canAny($page)
    {
        return $this->can($page);
    }

    /**
     * Checking if the user is a admin
     */
    public function isAdmin()
    {
        return $this->user && $this->user->isAdmin();
    }
}
