<?php namespace EscapeWork\Manager\Providers;

use Illuminate\Support\ServiceProvider;

class UserServiceProvider extends ServiceProvider
{

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->registerProvider();
        $this->registerAuthenticator();
        $this->registerUserResolver();
    }

    /**
     * Register the authenticator services.
     *
     * @return void
     */
    protected function registerAuthenticator()
    {
        $this->app['escapework.manager.auth.user'] = $this->app->share(function($app)
        {
            $guard = new \EscapeWork\Manager\Extensions\Auth\Guard(
                $app['escapework.manager.auth.user.provider'],
                $app['session.store']
            );

            $guard->setCookieJar($app['cookie']);
            $guard->setDispatcher($app['events']);

            return $guard->setRequest($app->refresh('request', $guard, 'setRequest'));
        });
    }

    /**
     * Register a resolver for the authenticated user.
     *
     * @return void
     */
    protected function registerUserResolver()
    {
        $this->app->bind('EscapeWork\Manager\Extensions\Auth\Guard', function () {
            return $this->app['escapework.manager.auth.user'];
        });
    }

    protected function registerProvider()
    {
        $this->app['escapework.manager.auth.user.provider'] = $this->app->share(function($app)
        {
            return new \Illuminate\Auth\EloquentUserProvider(
                $app['hash'],
                'EscapeWork\Manager\Models\User'
            );
        });
    }
}
